@@ -77,13 +77,14 @@ import tempfile
 import ctypes as ct  # type: ignore
 import _ctypes as _ct
 import logging
+import platform
 
 import numpy as np  # type: ignore
 
 try:
-    import tinycc
+    import tccbox
 except ImportError:
-    tinycc = None
+    tccbox = None
 
 from . import generate
 from .kernel import KernelModel, Kernel
@@ -112,7 +113,7 @@ else:
 if "SAS_COMPILER" in os.environ:
     COMPILER = os.environ["SAS_COMPILER"]
 elif os.name == 'nt':
-    if tinycc is not None:
+    if tccbox is not None:
         COMPILER = "tinycc"
     elif "VCINSTALLDIR" in os.environ:
         # If vcvarsall.bat has been called, then VCINSTALLDIR is in the
@@ -166,7 +167,17 @@ elif COMPILER == "msvc":
         return CC + ["/Tp%s"%source] + LN + ["/OUT:%s"%output]
 elif COMPILER == "tinycc":
     # TinyCC compiler.
-    CC = [tinycc.TCC] + "-shared -rdynamic -Wall".split()
+    CC = [
+        tccbox.tcc_bin_path(),
+        "-nostdinc",
+        "-std=c99",
+        f"-L{tccbox.tcc_lib_dir()}",
+        f"-L{joinpath(tccbox.tcc_lib_dir(), 'tcc')}",
+        f"-I{tccbox.tcc_dist_dir()}/include",
+        "-shared",
+        "-rdynamic",
+        "-Wall",
+    ]
     def compile_command(source, output):
         """tinycc compiler command"""
         return CC + [source, "-o", output]
@@ -210,7 +221,8 @@ def dll_name(model_file, dtype):
     any path or extension, with a form such as 'sas_sphere32'.
     """
     bits = 8*dtype.itemsize
-    basename = "sas%d_%s"%(bits, model_file)
+    arch = platform.machine()
+    basename = "sas%d_%s_%s"%(bits, arch, model_file)
     basename += ARCH + ".so"
 
     # Hack to find precompiled dlls.
